==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/invoice_statuses_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceStatusesController < AccountsManagementController
    # GET /documents/invoice_statuses
    # GET /documents/invoice_statuses.json
    def index
      @documents_invoice_statuses = Documents::InvoiceStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_invoice_statuses }
      end
    end

    # GET /documents/invoice_statuses/1
    # GET /documents/invoice_statuses/1.json
    def show
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_invoice_status }
      end
    end

    # GET /documents/invoice_statuses/new
    # GET /documents/invoice_statuses/new.json
    def new
      @documents_invoice_status = Documents::InvoiceStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_invoice_status }
      end
    end

    # GET /documents/invoice_statuses/1/edit
    def edit
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])
    end

    # POST /documents/invoice_statuses
    # POST /documents/invoice_statuses.json
    def create
      @documents_invoice_status = Documents::InvoiceStatus.new(params[:documents_invoice_status])

      respond_to do |format|
        if @documents_invoice_status.save
          format.html { redirect_to @documents_invoice_status, :notice => 'Invoice status was successfully created.' }
          format.json { render :json => @documents_invoice_status, :status => :created, :location => @documents_invoice_status }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_invoice_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_statuses/1
    # PUT /documents/invoice_statuses/1.json
    def update
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])

      respond_to do |format|
        if @documents_invoice_status.update_attributes(params[:documents_invoice_status])
          format.html { redirect_to @documents_invoice_status, :notice => 'Invoice status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_invoice_status.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_statuses/1
    # DELETE /documents/invoice_statuses/1.json
    def destroy
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])
      @documents_invoice_status.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/invoice_statuses_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceStatusesController < AccountsManagementController
    # GET /documents/invoice_statuses
    # GET /documents/invoice_statuses.json
    def index
      @documents_invoice_statuses = Documents::InvoiceStatus.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_invoice_statuses }
      end
    end

    # GET /documents/invoice_statuses/1
    # GET /documents/invoice_statuses/1.json
    def show
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_invoice_status }
      end
    end

    # GET /documents/invoice_statuses/new
    # GET /documents/invoice_statuses/new.json
    def new
      @documents_invoice_status = Documents::InvoiceStatus.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_invoice_status }
      end
    end

    # GET /documents/invoice_statuses/1/edit
    def edit
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])
    end

    # POST /documents/invoice_statuses
    # POST /documents/invoice_statuses.json
    def create
      @documents_invoice_status = Documents::InvoiceStatus.new(params[:documents_invoice_status])

      respond_to do |format|
        if @documents_invoice_status.save
          format.html { redirect_to @documents_invoice_status, notice: 'Invoice status was successfully created.' }
          format.json { render json: @documents_invoice_status, status: :created, location: @documents_invoice_status }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_invoice_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_statuses/1
    # PUT /documents/invoice_statuses/1.json
    def update
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])

      respond_to do |format|
        if @documents_invoice_status.update_attributes(params[:documents_invoice_status])
          format.html { redirect_to @documents_invoice_status, notice: 'Invoice status was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_invoice_status.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_statuses/1
    # DELETE /documents/invoice_statuses/1.json
    def destroy
      @documents_invoice_status = Documents::InvoiceStatus.find(params[:id])
      @documents_invoice_status.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_statuses_url }
        format.json { head :no_content }
      end
    end
  end
end
